@@ -462,9 +462,11 @@ class Q2Db:
         table_columns = self.get_database_columns(table_name[:])
         sql = (
             f"insert into {table_name} ("
-            + ",".join([f"{self.escape_char}{x}{self.escape_char}" for x in record.keys() if x in table_columns])
+            + ",".join(
+                [f"{self.escape_char}{x}{self.escape_char}" for x in record.keys() if x in table_columns]
+            )
             + ") values ("
-            + ",".join(["%s" for x in record.keys()])
+            + ",".join(["%s" for x in record.keys() if x in table_columns])
             + ")"
         )
 
